SelectoComponents.Dashboard.Widget (selecto_components v0.3.15)

Base component for dashboard widgets. Provides common functionality for all widget types.

Link to this section Summary

Functions

Renders a widget container with standard controls and content area.

Widget configuration modal component.

Link to this section Functions

Link to this function

widget(assigns)

Renders a widget container with standard controls and content area.

attributes

Attributes

  • id (:string) (required)
  • type (:atom) (required)
  • config (:map) - Defaults to %{}.
  • data (:any) - Defaults to nil.
  • class (:string) - Defaults to "".

slots

Slots

  • inner_block
  • header
  • footer
  • actions
Link to this function

widget_config_modal(assigns)

Widget configuration modal component.

attributes

Attributes

  • id (:string) (required)
  • widget_id (:string) (required)
  • config (:map) (required)
  • on_save (:any) (required)

slots

Slots

  • fields