SelectoComponents.Tenant (selecto_components v0.3.10)

Tenant scoping helpers for saved views and filter sets contexts.

This module provides a stable string key format that can be used to scope persistence adapters by tenant while preserving existing non-tenant behavior.

Link to this section Summary

Link to this section Functions

Link to this function

normalize_context(tenant_id)

@spec normalize_context(map() | keyword() | String.t() | atom() | nil) :: map() | nil
Link to this function

scoped_context(context, tenant_context, opts \\ [])

@spec scoped_context(term(), map() | keyword() | String.t() | atom() | nil, keyword()) ::
  term()