SelectoComponents.Helpers.Filters (selecto_components v0.4.5)
Link to this section Summary
Functions
Recursively build filters from form input that can be sent to Selecto.
Link to this section Functions
Link to this function
filter_recurse(selecto, filters, section)
Recursively build filters from form input that can be sent to Selecto.
Returns a list of filter tuples. Invalid or erroring filters are logged and skipped rather than crashing the entire filter chain.