SelectoComponents.Tenant (selecto_components v0.4.5)
Tenant scoping helpers for saved views and filter sets contexts.
This module provides a stable string key format that can be used to scope persistence adapters by tenant while preserving existing non-tenant behavior.
Link to this section Summary
Link to this section Functions
Link to this function
normalize_context(tenant_id)
Link to this function