SelectoComponents.ViewConfigManager (selecto_components v0.3.10)
Component for managing saved view configurations with view type separation. Allows saving and loading configurations specific to each view type.
Component for managing saved view configurations with view type separation. Allows saving and loading configurations specific to each view type.