SelectoComponents.Views.Graph.Process (selecto_components v0.4.5)
Link to this section Summary
Functions
Process aggregate fields (for Y-axis)
Process group by fields (for X-axis and Series)
Initial state when view is created without params
Converts form parameters to view state for form rendering
Converts parameters into Selecto query structure
Link to this section Functions
Link to this function
aggregate_defs(aggregate_params, columns)
Link to this function
aggregate_fields(aggregate_params, columns)
Process aggregate fields (for Y-axis)
Link to this function
group_by_fields(field_params, columns)
Process group by fields (for X-axis and Series)
Link to this function
initial_state(selecto, view)
Initial state when view is created without params
Link to this function
param_to_state(params, view)
Converts form parameters to view state for form rendering
Link to this function
view(opt, params, columns, filtered, selecto)
Converts parameters into Selecto query structure